==> enpls_5.9.tar.gz: enpls/README.md <==
# enpls  <a href="https://enpls.org"><img src="https://nanx.me/images/project-enpls.png" align="right" alt="logo" height="180" width="180" /></a>

[![Build Status](https://travis-ci.org/road2stat/enpls.svg?branch=master)](https://travis-ci.org/road2stat/enpls)
[![AppVeyor Build Status](https://ci.appveyor.com/api/projects/status/github/road2stat/enpls?branch=master&svg=true)](https://ci.appveyor.com/project/road2stat/enpls)
[![CRAN Version](https://www.r-pkg.org/badges/version/enpls)](https://cran.r-project.org/package=enpls)
[![Downloads from the RStudio CRAN mirror](https://cranlogs.r-pkg.org/badges/enpls)](https://cranlogs.r-pkg.org/badges/enpls)

`enpls` offers an algorithmic framework for measuring feature importance, outlier detection, model applicability domain evaluation, and ensemble predictive modeling with (sparse) partial least squares regressions.

## Installation

Install `enpls` from CRAN:

```r
install.packages("enpls")
```

Or try the development version on GitHub:

```r
# install.packages("devtools")
devtools::install_github("road2stat/enpls")
```

See [the vignette](https://enpls.org/doc/) (or open with `vignette("enpls")` in R) for a quick-start guide.

## Gallery

### Measuring Feature Importance

<img src="https://enpls.org/img/enpls-featimp.png" width="100%" alt="enpls-fs">

### Outlier Detection

<img src="https://enpls.org/img/enpls-outlier.png" width="100%" alt="enpls-od">

### Model Applicability Domain Evaluation / Ensemble Predictive Modeling

<img src="https://enpls.org/img/enpls-model.png" width="100%" alt="enpls-fit">

## Links

* Web: [https://enpls.org](https://enpls.org)
* CRAN: [https://cran.r-project.org/package=enpls](https://cran.r-project.org/package=enpls)
* GitHub: [https://github.com/road2stat/enpls](https://github.com/road2stat/enpls)

## Contribute

To contribute to this project, please take a look at the [Contributing Guidelines](CONTRIBUTING.md) first. Please note that this project is released with a [Contributor Code of Conduct](CONDUCT.md). By participating in this project you agree to abide by its terms.

==> enpls_6.0.tar.gz: enpls/README.md <==
# enpls  <a href="https://nanx.me/enpls/"><img src="https://nanx.me/images/project-enpls.png" align="right" alt="logo" height="180" width="180" /></a>

[![Build Status](https://travis-ci.org/road2stat/enpls.svg?branch=master)](https://travis-ci.org/road2stat/enpls)
[![AppVeyor Build Status](https://ci.appveyor.com/api/projects/status/github/road2stat/enpls?branch=master&svg=true)](https://ci.appveyor.com/project/road2stat/enpls)
[![CRAN Version](https://www.r-pkg.org/badges/version/enpls)](https://cran.r-project.org/package=enpls)
[![Downloads from the RStudio CRAN mirror](https://cranlogs.r-pkg.org/badges/enpls)](https://cranlogs.r-pkg.org/badges/enpls)

`enpls` offers an algorithmic framework for measuring feature importance, outlier detection, model applicability domain evaluation, and ensemble predictive modeling with (sparse) partial least squares regressions.

## Installation

Install `enpls` from CRAN:

```r
install.packages("enpls")
```

Or try the development version on GitHub:

```r
# install.packages("devtools")
devtools::install_github("road2stat/enpls")
```

See [the vignette](https://nanx.me/enpls/articles/enpls.html) (or open with `vignette("enpls")` in R) for a quick-start guide.

## Gallery

### Measuring Feature Importance

<img src="https://nanx.me/enpls/img/enpls-featimp.png" width="100%" alt="enpls-fs">

### Outlier Detection

<img src="https://nanx.me/enpls/img/enpls-outlier.png" width="100%" alt="enpls-od">

### Model Applicability Domain Evaluation / Ensemble Predictive Modeling

<img src="https://nanx.me/enpls/img/enpls-model.png" width="100%" alt="enpls-fit">

## Links

* Web: [https://nanx.me/enpls/](https://nanx.me/enpls/)
* CRAN: [https://cran.r-project.org/package=enpls](https://cran.r-project.org/package=enpls)
* GitHub: [https://github.com/road2stat/enpls](https://github.com/road2stat/enpls)

## Contribute

To contribute to this project, please take a look at the [Contributing Guidelines](CONTRIBUTING.md) first. Please note that this project is released with a [Contributor Code of Conduct](CONDUCT.md). By participating in this project you agree to abide by its terms.
